@@ -91,13 +91,10 @@ fn download_to_temp(
     let temp_dir = TempDir::new()?;
     let temp_file = temp_dir.path().join("download");
 
-    let client = reqwest::blocking::Client::builder()
-        .connect_timeout(Duration::from_secs(30))
-        .timeout(None)
-        .build()?;
+    let client = reqwest::blocking::Client::new();
 
     let progress_bar = new_spinner_progress_bar();
-    progress_bar.set_message(&format!("{}Downloading...", TRUCK));
+    progress_bar.set_message(format!("{}Downloading...", TRUCK));
 
     let response = client.get(url.as_str()).send()?;
     let download_size = {
@@ -117,7 +114,7 @@ fn download_to_temp(
             )
             .progress_chars("=> "),
     );
-    progress_bar.set_message(&format!("{}Downloading", TRUCK));
+    progress_bar.set_message(format!("{}Downloading", TRUCK));
 
     struct DownloadProgress<R> {
         progress_bar: ProgressBar,
@@ -160,7 +157,7 @@ fn extract_release_archive(
     use {bzip2::bufread::BzDecoder, tar::Archive};
 
     let progress_bar = new_spinner_progress_bar();
-    progress_bar.set_message(&format!("{}Extracting...", PACKAGE));
+    progress_bar.set_message(format!("{}Extracting...", PACKAGE));
 
     if extract_dir.exists() {
         let _ = fs::remove_dir_all(&extract_dir);
@@ -220,7 +217,7 @@ fn new_update_manifest(
         .get_account_data(&update_manifest_keypair.pubkey())
         .is_err()
     {
-        let (recent_blockhash, _fee_calculator) = rpc_client.get_recent_blockhash()?;
+        let recent_blockhash = rpc_client.get_latest_blockhash()?;
 
         let lamports = rpc_client
             .get_minimum_balance_for_rent_exemption(SignedUpdateManifest::max_space() as usize)?;
@@ -246,7 +243,7 @@ fn store_update_manifest(
     update_manifest_keypair: &Keypair,
     update_manifest: &SignedUpdateManifest,
 ) -> Result<(), Box<dyn std::error::Error>> {
-    let (recent_blockhash, _fee_calculator) = rpc_client.get_recent_blockhash()?;
+    let recent_blockhash = rpc_client.get_latest_blockhash()?;
 
     let signers = [from_keypair, update_manifest_keypair];
     let instruction = config_instruction::store::<SignedUpdateManifest>(
@@ -702,7 +699,7 @@ pub fn deploy(
     // Confirm the `json_rpc_url` is good and that `from_keypair` is a valid account
     let rpc_client = RpcClient::new(json_rpc_url.to_string());
     let progress_bar = new_spinner_progress_bar();
-    progress_bar.set_message(&format!("{}Checking cluster...", LOOKING_GLASS));
+    progress_bar.set_message(format!("{}Checking cluster...", LOOKING_GLASS));
     let balance = rpc_client
         .get_balance(&from_keypair.pubkey())
         .map_err(|err| {
@@ -751,7 +748,7 @@ pub fn deploy(
     println_name_value("Update target:", &release_target);
 
     let progress_bar = new_spinner_progress_bar();
-    progress_bar.set_message(&format!("{}Deploying update...", PACKAGE));
+    progress_bar.set_message(format!("{}Deploying update...", PACKAGE));
 
     // Construct an update manifest for the release
     let mut update_manifest = SignedUpdateManifest {
@@ -833,7 +830,7 @@ pub fn gc(config_file: &str) -> Result<(), String> {
                     .template("{spinner:.green}{wide_msg} [{bar:40.cyan/blue}] {pos}/{len} ({eta})")
                     .progress_chars("=> "),
             );
-            progress_bar.set_message(&format!("{}Removing old releases", RECYCLING));
+            progress_bar.set_message(format!("{}Removing old releases", RECYCLING));
             for (release, _modified_type) in old_releases {
                 progress_bar.inc(1);
                 let _ = fs::remove_dir_all(&release);
@@ -942,7 +939,7 @@ pub fn init_or_update(config_file: &str, is_init: bool, check_only: bool) -> Res
         match explicit_release {
             ExplicitRelease::Semver(current_release_semver) => {
                 let progress_bar = new_spinner_progress_bar();
-                progress_bar.set_message(&format!("{}Checking for updates...", LOOKING_GLASS));
+                progress_bar.set_message(format!("{}Checking for updates...", LOOKING_GLASS));
 
                 let github_release = check_for_newer_github_release(
                     semver::VersionReq::parse(&format!(
@@ -1064,7 +1061,7 @@ pub fn init_or_update(config_file: &str, is_init: bool, check_only: bool) -> Res
         }
     } else {
         let progress_bar = new_spinner_progress_bar();
-        progress_bar.set_message(&format!("{}Checking for updates...", LOOKING_GLASS));
+        progress_bar.set_message(format!("{}Checking for updates...", LOOKING_GLASS));
         let rpc_client = RpcClient::new(config.json_rpc_url.clone());
         let update_manifest = get_update_manifest(&rpc_client, &config.update_manifest_pubkey)?;
         progress_bar.finish_and_clear();
